function    g = lfmGradientSigmaH(gamma1, gamma2, sigma2, t1, t2);

% LFMGRADIENTSIGMAH Gradient of the function h_i(z) with respect \sigma.
%
%	Description:
%
%	G = LFMGRADIENTSIGMAH(GAMMA1, GAMMA2, SIGMA2, T1, T2) Computes the
%	gradient of the function h_i(z) with respect to the length-scale of
%	the input "force", \sigma.
%	 Returns:
%	  G - Gradient of the function with respect to \sigma.
%	 Arguments:
%	  GAMMA1 - Gamma value for first system.
%	  GAMMA2 - Gamma value for second system.
%	  SIGMA2 - length scale of latent process.
%	  T1 - first time input (number of time points x 1).
%	  T2 - second time input (number of time points x 1).
%	
%
%	See also
%	LFMKERNGRADIENT, LFMXLFMKERNGRADIENT, LFMGRADIENTSIGMAUPSILON


%	Copyright (c) 2007, 2008 David Luengo
% 	lfmGradientSigmaH.m SVN version 11
% 	last update 2008-06-05T18:41:50.000000Z


% Creation of the time matrices

Tt1 = repmat(t1,1,size(t2, 1));
Tt2 = repmat(t2',size(t1, 1),1);

% Gradient

g = (lfmGradientSigmaUpsilon(gamma1,sigma2,Tt2,Tt1) - exp(-gamma2*Tt1) ...
    .*lfmGradientSigmaUpsilon(gamma1,sigma2,Tt2,zeros(size(Tt1))))/(gamma1+gamma2);
